Skip to contents

Panel sections refer to bind ids created by components such as add_views(), add_filters(), and add_summaries().

Usage

section(id)

Arguments

id

Bind id (e.g. the bind supplied to add_views/add_filters, or the component id when bind is omitted).

Value

A panel section object.

Examples

section("filters")
#> $id
#> [1] "filters"
#> 
#> attr(,"class")
#> [1] "maplamina_panel_section"