R/add_panel.R
section.Rd
Panel sections refer to bind ids created by components such as add_views(), add_filters(), and add_summaries().
add_views()
add_filters()
add_summaries()
section(id)
Bind id (e.g. the bind supplied to add_views/add_filters, or the component id when bind is omitted).
bind
A panel section object.
section("filters") #> $id #> [1] "filters" #> #> attr(,"class") #> [1] "maplamina_panel_section"